@@ -5,8 +5,9 @@ use warnings;
 package Story::Interact;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001004';
+our $VERSION   = '0.001005';
 
+use Story::Interact::Analyze ();
 use Story::Interact::Character ();
 use Story::Interact::Harness::Terminal ();
 use Story::Interact::Page ();
@@ -16,6 +17,27 @@ use Story::Interact::PageSource::Dir ();
 use Story::Interact::State ();
 use Story::Interact::Syntax ();
 
+sub new_page_source {
+	my ( undef, $story ) = @_;
+
+	if ( -d $story ) {
+		return Story::Interact::PageSource::Dir->new( dir => $story );
+	}
+	elsif ( $story =~ /^dbi:/i ) {
+		require DBI;
+		my $dbh = DBI->connect( $story, undef, undef );
+		return Story::Interact::PageSource::DBI->new( dbh => $dbh );
+	}
+	elsif ( -f $story ) {
+		require DBI;
+		my $dbh = DBI->connect( "dbi:SQLite:dbname=$story", '', '' );
+		return Story::Interact::PageSource::DBI->new( dbh => $dbh );
+	}
+
+	require Carp;
+	Carp::croak("Could not open '$story' as a page source");
+}
+
 1;
 
 __END__
@@ -147,6 +169,8 @@ L<https://github.com/tobyink/p5-story-interact/issues>.
 
 L<Pod::CYOA>, L<https://en.wikipedia.org/wiki/Choose_Your_Own_Adventure>.
 
+L<Story::Interact::WWW>: Mojo-based web interface for Story::Interact.
+
 =head1 AUTHOR
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
